@@ -3,7 +3,9 @@ from parser_libraries import functions as f
 from bs4 import BeautifulSoup
 import logging
 import logging.handlers
+import urllib3
 
+urllib3.disable_warnings(urllib3.exceptions.InsecureRequestWarning)
 
 logging.basicConfig(format=f'%(module)s.{__name__}: %(message)s')
 log = logging.getLogger(__name__)
